%global __provides_exclude_from ^%{_libdir}/stunnel/.*$

Summary:       A TLS-encrypting socket wrapper
Name:          stunnel
Version:       5.62
Release:       6%{?dist}
License:       GPLv2
URL:           https://www.stunnel.org/
Source0:       https://www.stunnel.org/downloads/stunnel-%{version}.tar.gz
Source1:       https://www.stunnel.org/downloads/stunnel-%{version}.tar.gz.asc
Source2:       Certificate-Creation
Source3:       sfinger.xinetd
Source4:       stunnel-sfinger.conf
Source5:       pop3-redirect.xinetd
Source6:       stunnel-pop3s-client.conf
Source7:       stunnel@.service

Patch3000:     stunnel-5.50-authpriv.patch
Patch3001:     stunnel-5.61-systemd-service.patch
Patch3003:     stunnel-5.56-system-ciphers.patch
Patch3004:     stunnel-5.56-coverity.patch
Patch3005:     stunnel-5.61-default-tls-version.patch
Patch3006:     stunnel-5.56-curves-doc-update.patch
Patch3007:     stunnel-5.61-fips-test.patch

BuildRequires: make gcc openssl-devel pkgconfig util-linux
BuildRequires: autoconf automake libtool
BuildRequires: /usr/bin/pod2man /usr/bin/pod2html
BuildRequires: /usr/bin/nc /usr/bin/lsof /usr/bin/ps
BuildRequires: python3 openssl systemd
%{?systemd_requires}

%description
Stunnel is a socket wrapper which can provide TLS/SSL (Transport Layer
Security/Secure Sockets Layer) support to ordinary applications.
For example, it can be used in conjunction with imapd to create a TLS secure IMAP server.

%prep
%autosetup -n %{name}-%{version} -p1
sed -i 's/-fstack-protector/-fstack-protector-strong/' configure

%build
CFLAGS="$RPM_OPT_FLAGS -fPIC"; export CFLAGS
if pkg-config openssl ; then
	CFLAGS="$CFLAGS `pkg-config --cflags openssl`";
	LDFLAGS="`pkg-config --libs-only-L openssl`"; export LDFLAGS
fi
%configure \
    --enable-fips \
    --enable-ipv6 \
    --with-ssl=%{_prefix} \
    --disable-libwrap \
	CPPFLAGS="-UPIDFILE -DPIDFILE='\"%{_localstatedir}/run/stunnel.pid\"'"
make V=1 LDADD="-pie -Wl,-z,defs,-z,relro,-z,now"

%install
%make_install
for lang in pl ; do
	mkdir -p %{buildroot}/%{_mandir}/${lang}/man8
	mv %{buildroot}/%{_mandir}/man8/*.${lang}.8* %{buildroot}/%{_mandir}/${lang}/man8/
	rename ".${lang}" "" %{buildroot}/%{_mandir}/${lang}/man8/*
done
mkdir srpm-docs
cp %{SOURCE2} %{SOURCE3} %{SOURCE4} %{SOURCE5} %{SOURCE6} srpm-docs
install -D %{buildroot}%{_datadir}/doc/stunnel/examples/%{name}.service %{buildroot}%{_unitdir}/%{name}.service
install -p %{SOURCE7} %{buildroot}%{_unitdir}/%{name}@.service

%check
make test || (for i in tests/logs/*.log ; do echo "$i": ; cat "$i" ; done)

%post
/sbin/ldconfig
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
/sbin/ldconfig
%systemd_postun_with_restart %{name}.service

%files
%license COPY*
%doc AUTHORS.md BUGS.md CREDITS.md PORTS.md README.md TODO.md
%doc tools/stunnel.conf-sample
%doc srpm-docs/*
%lang(en) %doc doc/en/*
%lang(pl) %doc doc/pl/*
%{_bindir}/stunnel
%{_libdir}/stunnel
%dir %{_sysconfdir}/%{name}
%{_unitdir}/%{name}*.service
%{_datadir}/bash-completion/completions/%{name}.bash
%{_mandir}/man8/stunnel.8*
%lang(pl) %{_mandir}/pl/man8/stunnel.8*
%exclude %{_bindir}/stunnel3
%exclude %{_datadir}/doc/stunnel
%exclude %{_libdir}/stunnel/libstunnel.la
%exclude %{_sysconfdir}/stunnel/*

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.62-6
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.62-5
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.62-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.62-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.62-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Nov 18 2022 Shuo Wang <abushwang@tencent.com> - 5.62-1 
- initial build

